## [Variation in PCA weights](http://stats.stackexchange.com/questions/1708/variation-in-pca-weights)

It looks like you are referring to eigenanalysis for SNPs data and the article from Nick Patterson, [Population Structure and Eigenanalysis][1] (PLoS Genetics 2006), where the first component explains the largest variance on allele frequency wrt. potential stratification in the sample (due to ethnicity or, more generally, ancestry). So I wonder why you want to consider all three first components, unless they appear to be significant from their expected distribution according to [TW distribution][2]. Anyway, in R you can isolate the most informative SNPs (i.e. those that are at the extreme of the successive principal axes) with the `apply()` function, working on row, e.g.

    apply(snp.df, 1, function(x) any(abs(x)>threshold))

where `snp.df` stands for the data you show and which is stored either as a `data.frame` or `matrix` under R, and `threshold` is the value you want to consider (this can be Mean $\pm$ 6 SD, as in Price et al. *Nature Genetics* 2007 38(8): 904, or whatever value you want).
You may also implement the iterative PCA yourself.

Finally, the TW test can be implemented as follows:

    ##' Test for the largest eigenvalue in a gaussian covariance matrix
    ##' 
    ##' This function computes the test statistic and associated p-value
    ##' for a Wishart matrix focused on individuals (Tracy-Widom distribution).
    ##' 
    ##' @param C a rectangular matrix of bi-allelic markers (columns) indexed
    ##'        on m individuals. Caution: genotype should be in {0,1,2}.
    ##' @return test statistic and tabulated p-value
    ##' @reference \cite{Johnstone:2001}
    ##' @seealso The RMTstat package provides other interesting functions to
    ##'          deal with Wishart matrices.
    ##' @example
    ##' X <- replicate(100,sample(0:2,20,rep=T))
    tw.test <- function(C) {
      m <- nrow(C)  # individuals
      n <- ncol(C)  # markers
      # compute M
      C <- scale(C, scale=F)
      pj <- attr(C,"scaled:center")/2
      M <- C/sqrt(pj*(1-pj))
      # compute X=MM'
      X <- M %*% t(M)
      ev <- sort(svd(X)$d, decr=T)[1:(m-1)]
      nprime <- ((m+1)*sum(ev)^2)/(((m-1)*sum(ev^2))-sum(ev)^2)
      l <- (m-1)*ev[1]/sum(ev)
      # normalize l and compute test statistic
      num <- (sqrt(nprime-1)+sqrt(m))
      mu <- num^2/nprime
      sigma <- num/nprime*(1/sqrt(nprime-1)+1/sqrt(m))^(1/3)
      l <- (l-mu)/sigma
      # estimate associated p-value
      if (require(RMTstat)) pv <- ptw(l, lower.tail=F)
      else pv <- NA
      return(list(stat=l, pval=pv))
    }


  [1]: http://www.plosgenetics.org/article/info:doi/10.1371/journal.pgen.0020190
  [2]: http://j.mp/cHQnxw
