## [Testing paired frequencies for independence](http://stats.stackexchange.com/questions/5171/testing-paired-frequencies-for-independence)

[Log-linear models][1] might be another option to look at, if you want to study your two-way data structure.

If you assume that the two samples are matched (i.e., there is some kind of dependency between the two series of locutions) and you take into consideration that data are actually counts that can be considered as scores or ordered responses (as suggested by @caracal), then you can also look at marginal models for matched-pairs, which usually involve the analysis of a square contingency table. It may not be necessarily the case that you end up with such a square Table, but we can also decide of an upper-bound for the number of, e.g. passive sentences. Anyway, models for matched pairs are well explained in Chapter 10 of Agresti, *[Categorical Data Analysis][2]*; relevant models for ordinal categories in square tables are testing for *quasi-symmetry* (the difference in the effect of a category from one case to the other follows a linear trend in the category scores), *conditional symmetry* ($\pi_{ab}<\pi_{ab}$ or $\pi_{ab}>\pi_{ab}$, $\forall a,b$), and *quasi-uniform association* (linear-by-linear association off the main diagonal, which in the case of equal-interval scores means an uniform local association). Ordinal quasi-symmetry (OQS) is a special case of linear logit model, and it can be compared to a simpler model where only *marginal homogeneity* holds with an LR test, because ordinal quasi-symmetry + marginal homogeneity $=$ symmetry.

Following Agresti's notation (p. 429), we consider $u_1\leq\dots\leq u_I$ ordered scores for variable $X$ (in rows) and variable $Y$ (in columns); $a$ or $b$ denotes any row or column. The OQS model reads as the following log-linear model:

$$
\log\mu_{ab}=\lambda+\lambda_a+\lambda_b+\beta u_b +\lambda_{ab}
$$

where $\lambda_{ab}=\lambda_{ba}$ for all $a<b$. Compared to the usual QS model for nominal data which is $\log\mu_{ab}=\lambda+\lambda_a^X+\lambda_b^Y+\lambda_{ab}$, where $\lambda_{ab}=0$ would mean independence between the two variables, in the OQS model we impose $\lambda_b^Y-\lambda_b^X=\beta u_b$ (hence introducing the idea of a linear trend). The equivalent logit representation is $\log(\pi_{ab}/\pi_{ba})=\beta(u_b-u_a)$, for $a\leq b$.

If $\beta=0$, then we have symmetry as a special case of this model. If $\beta\neq 0$, then we have stochastically ordered margins, that is $\beta>0$ means that column mean is higher compared to row mean (and the greater $|\beta|$, the greater the differences between the two joint probabilities distributions $\pi_{ab}$ and $\pi_{ba}$ are, which will be reflected in the differences between row and column marginal distributions). A test of $\beta=0$ corresponds to a test of marginal homogeneity. The interpretation of the estimated $\beta$ is straightforward: the estimated probability that score on variable $X$ is $x$ units more positive than the score on $Y$ is $\exp(\hat\beta x)$ times the reverse probability. In your particular case, it means that $\hat\beta$ might allow to quantify the influence that one particular speaker exerts on the other.

Of note, all R code was made available by Laura Thompson in her [S Manual to Accompany Agresti's Categorical Data Analysis][3].

Hereafter, I provide some example R code so that you can play with it on your own data. So, let's try to generate some data first:

    set.seed(56)
    d <- as.data.frame(replicate(2, rpois(420, 1.5)))
    colnames(d) <- paste("S", 1:2, sep="")
    d.tab <- table(d$S1, d$S2, dnn=names(d)) # or xtabs(~S1+S2, d)
    library(vcdExtra)
    structable(~S1+S2, data=d)
    # library(ggplot2)
    # ggfluctuation(d.tab, type="color") + labs(x="S1", y="S2") + theme_bw()

Visually, the cross-classification looks like this:

       S2  0  1  2  3  4  5  6
    S1                        
    0     17 35 31  8  7  3  0
    1     41 41 30 23  7  2  0
    2     19 43 18 18  5  0  1
    3     11 21  9 15  2  1  0
    4      0  3  4  1  0  0  0
    5      1  0  0  2  0  0  0
    6      0  0  0  1  0  0  0

Now, we can fit the OQS model. Unlike Laura Thompson which used the base `glm()` function and a custom design matrix for symmetry, we can rely on the [gnm][4] package; we need, however, to add a vector for numerical scores to estimate $\beta$ in the above model.

    library(gnm)
    d.long <- data.frame(counts=c(d.tab), S1=gl(7,1,7*7,labels=0:6),
                         S2=gl(7,7,7*7,labels=0:6))
    d.long$scores <- rep(0:6, each=7)
    summary(mod.oqs <- gnm(counts~scores+Symm(S1,S2), data=d.long, 
                           family=poisson))
    anova(mod.oqs)

Here, we have $\hat\beta=0.123$, and thus the probability that Speaker B scores 4 when Speaker A scores 3 is $\exp(0.123)=1.13$ times the probability that Speaker B have a score of 3 while Speaker A have a score of 4.

I recently came across the [catspec][5] R package which seems to offer similar facilities, but I didn't try it. There was a good tutorial at UseR! 2009 about all this stuff: [Introduction to Generalized Nonlinear Models in R][6], but see also the accompagnying vignette, [Generalized nonlinear models in R: An overview of the gnm package][7].

If you want to grasp the idea with real data, there are a lot of examples with real data sets in the [vcdExtra][8] package from Michael Friendly. About the OQS model, Agresti used data on Premarital Sex and Extramarital sex (Table 10.5, p. 421). Results are discussed in §10.4.7 (p. 430), and $\hat\beta$ was estimated at -2.86. The code below allow (partly grabbed from Thompson's textbook) to reproduce these results. We would need to relevel factor levels so as to set the same baseline than Agresti.

    table.10.5 <- data.frame(expand.grid(PreSex=factor(1:4),
                                         ExSex=factor(1:4)),
                             counts=c(144,33,84,126,2,4,14,29,0,2,6,25,0,0,1,5))
    table.10.5$scores <- rep(1:4,each=4)
    summary(mod.oqs <- gnm(counts~scores+Symm(PreSex,ExSex), data=table.10.5, 
                           family=poisson)) # beta = -2.857
    anova(mod.oqs) # G^2(5)=2.10


  [1]: http://en.wikipedia.org/wiki/Poisson_regression
  [2]: http://www.stat.ufl.edu/~aa/cda/cda.html
  [3]: https://home.comcast.net/~lthompson221/Splusdiscrete2.pdf
  [4]: http://cran.r-project.org/web/packages/gnm/index.html
  [5]: http://cran.r-project.org/web/packages/catspec/index.html
  [6]: http://www.r-project.org/conferences/useR-2009/tutorials/gnmCourse-3up.pdf
  [7]: http://cran.r-project.org/web/packages/gnm/vignettes/gnmOverview.pdf
  [8]: http://cran.r-project.org/web/packages/vcdExtra/index.html
