## [What logistic regression is best to use?](http://stats.stackexchange.com/questions/5762/what-logistic-regression-is-best-to-use)

Logistic regression is to be used when the outcome of interest is a binary variable (e.g., success/failure), whereas multinomial logistic is reserved for the case of a multi-category response variable (e.g., blue/red/green). In both cases, the response variable to be predicted is a categorical variable. The predictors might be categorical or continuous variables.

From what you described, you are interested in predicting scores on a social attribution task based on observed scores on a reading scores. If both sets of scores are numerical, then it is simply a linear regression model. In R, it is something like

    # fake data
    x <- rnorm(100)
    y <- 1.2*x + rnorm(100)
    # model fit
    summary(lm(y ~ x))

The output reads:


    Call:
    lm(formula = y ~ x)
    
    Residuals:
        Min      1Q  Median      3Q     Max 
    -2.6635 -0.6227 -0.1589  0.6360  2.2494 
    
    Coefficients:
                Estimate Std. Error t value Pr(>|t|)    
    (Intercept) -0.03769    0.10042  -0.375    0.708    
    x            1.31590    0.10796  12.188   <2e-16 ***
    ---
    Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1 
    
    Residual standard error: 1.003 on 98 degrees of freedom
    Multiple R-squared: 0.6025,	Adjusted R-squared: 0.5985 
    F-statistic: 148.6 on 1 and 98 DF,  p-value: < 2.2e-16 

Here an increase of one unit in $x$ is associated to an increase of 1.32 units in $y$. This is basically what the regression coefficient tells you when you assume a model like $\mathbb{E}(y|x)=\beta_0+\beta_1x+\varepsilon$, where $\varepsilon$ are independent and identically distributed as a centered gaussian with variance $\sigma^2$ (unknown).

Now, you may still be interested in a binary outcome. For instance, I can define "Success" as $y>0$. In this case, a logistic regression would look like

    yb <- ifelse(y>0, 1, 0)
    summary(glm(yb ~ x, family=binomial))

where the regression coefficient gives you the log of the odds of passing the exam (compared to failing to reach a score of 0):


    Coefficients:
                Estimate Std. Error z value Pr(>|z|)    
    (Intercept)  -0.5047     0.3194  -1.580    0.114    
    x             3.3959     0.6871   4.943  7.7e-07 ***
    ---
    Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1 


**Edit**

Some pointers with multinomial logistic regression have already been given. What I wonder is the outcome you want to model: If you're interested in whether the autistic group has lower scores on the attribution task (as would be expected from the literature), then in a logistic model both scores will be continuous predictors, and reading scores will be considered as a covariate; in other words, you model the odds of being in one of the diagnostic class as a function of attrition task, after adjusting for baseline differences in language proficiency. But it seems it would make sense only if the diagnostic categories are not *a priori* defined and it does not directly answer the question you are asking (whether language is a predictor for attrition that may act differentially according to the diagnostic group); otherwise, I would rather model the attrition scores as a function of a grouping variable (diagnostic category) + reading scores, which is basically an [ANCOVA][1] model.

Both models are available in R: `mlogit()` in the package [mlogit][2] for multinomial logistic regression, and `lm()` for ANCOVA.


  [1]: http://en.wikipedia.org/wiki/Analysis_of_covariance
  [2]: http://cran.r-project.org/web/packages/mlogit/index.html
